import { Component, OnInit } from '@angular/core';
import { Observable, of } from 'rxjs';
import {
  pluck,
  shareReplay,
  switchMap,
  catchError,
  tap,
  filter,
  map,
} from 'rxjs';
import { Post } from '../posts/posts.component';
import { isScullyGenerated, TransferStateService } from '@scullyio/ng-lib';
import { ActivatedRoute } from '@angular/router';
import { HttpClient } from '@angular/common/http';

@Component({
  selector: 'app-post',
  templateUrl: './post.component.html',
  styleUrls: ['./post.component.css'],
})
export class PostComponent implements OnInit {
  postId$: Observable<number> = this.route.params.pipe(
    pluck('postId'),
    filter((val) => ![undefined, null].includes(val)),
    map((val) => parseInt(val, 10)),
    shareReplay(1)
  );

  apiPosts$ = this.postId$.pipe(
    switchMap((id) =>
      this.http.get<Post>(`/api/posts/${id}`).pipe(
        catchError(() =>
          of({
            id,
            title: 'not found',
          } as Post)
        )
      )
    ),
    shareReplay(1)
  );

  // This is an example of using TransferState
  post$ = isScullyGenerated()
    ? this.transferState.getState<Post>('post')
    : this.apiPosts$.pipe(
        tap((post) => this.transferState.setState('post', post))
      );

  constructor(
    private route: ActivatedRoute,
    private http: HttpClient,
    private transferState: TransferStateService
  ) {}

  ngOnInit() {}
}
