---
title: Syntax Highlighting using PrismJS
published: true
lang: en
position: 100
---

# Syntax Highlighting with PrismJS

## Overview

> ## NOTE: Scully supports Prism now natively, see [marked](../plugins/built-in-plugins/md.md)

[Prism](https://prismjs.com/) is a lightweight, extensible syntax highlighter that can be used when working with code blocks in markdown files in blog posts.

It is possible to define a language for the code to be used in the Scully code like this:

<pre><code>
```typescript
const foo = 'bar';
```
</code></pre>

## How Scully Handles Code Blocks

Scully parses the markdown using [_marked_](https://www.npmjs.com/package/marked), and the parsed result looks like this:

```html
<code class="language-ts">
  <span class="token keyword">const</span> foo
  <span class="token operator">=</span>
  <span class="token string">'bar'</span>
  <span class="token punctuation">;</span>
</code>
```

_marked_ uses the CSS class prefix `language-` to tag the code block with an appropriate language.

## Usage

To highlight the code blocks use [_prismjs_](https://prismjs.com) and create a service like this:

```bash
npm i --save prismjs
ng g s highlight
```

The service will include all languages needed. The code looks like this:

```typescript
import { Injectable, Inject } from '@angular/core';

import { PLATFORM_ID } from '@angular/core';
import { isPlatformBrowser } from '@angular/common';

import 'clipboard';
import 'prismjs';
import 'prismjs/plugins/toolbar/prism-toolbar';
import 'prismjs/plugins/copy-to-clipboard/prism-copy-to-clipboard';
import 'prismjs/components/prism-bash';
import 'prismjs/components/prism-css';
import 'prismjs/components/prism-javascript';
import 'prismjs/components/prism-json';
import 'prismjs/components/prism-markup';
import 'prismjs/components/prism-typescript';
// ... probably more, check out node_modules/prismjs/components

declare var Prism: any;

@Injectable({ providedIn: 'root' })
export class HighlightService {
  constructor(@Inject(PLATFORM_ID) private platformId: Object) {}

  highlightAll() {
    if (isPlatformBrowser(this.platformId)) {
      Prism.highlightAll();
    }
  }
}
```

Now, it needs to inject the service in the `BlogComponent` that was generated by Scully:

```typescript
import {/* ... */, AfterViewChecked} from '@angular/core';
import {HighlightService} from '../highlight.service';
/* ... */
export class BlogComponent implements OnInit, AfterViewChecked {
  constructor(
    /* ... */
    private highlightService: HighlightService
  ) {}
  /* ... */
  ngAfterViewChecked() {
    this.highlightService.highlightAll();
  }
}
```

Finally, include a Prism's theme like this:

```css
/* include CSS for prism toolbar */
@import '~prismjs/plugins/toolbar/prism-toolbar.css';
/* check node_modules/prismjs/themes/ for the available themes */
@import '~prismjs/themes/prism-tomorrow';
```

Visit [prismjs](https://prismjs.com/) for more information.
